@@ -5,12 +5,12 @@ Parser for multipart/form-data
 
 This module provides a parser for the multipart/form-data format. It can read
 from a file, a socket or a WSGI environment. The parser can be used to replace
-cgi.FieldStorage (without the bugs) and works with Python 2.5+ and 3.x (2to3).
+cgi.FieldStorage to work around its limitations.
 """
 
 
 __author__ = "Marcel Hellkamp"
-__version__ = "0.2.3"
+__version__ = "0.2.4"
 __license__ = "MIT"
 __all__ = ["MultipartError", "MultipartParser", "MultipartPart", "parse_form_data"]
 
@@ -517,7 +517,7 @@ def parse_form_data(environ, charset="utf8", strict=False, **kwargs):
             if stream.read(1):  # These is more that does not fit mem_limit
                 raise MultipartError("Request too big. Increase MAXMEM.")
 
-            data = parse_qs(data, keep_blank_values=True)
+            data = parse_qs(data, keep_blank_values=True, encoding=charset)
 
             for key, values in data.items():
                 for value in values:
